@@ -14,23 +14,22 @@ from six import string_types
 
 from zerobug import z0testodoo
 
-if sys.version_info[0] == 2:
+try:
     from getaddons import (get_addons, get_applications_with_dependencies,
                            get_dependencies, get_localizations_with_dependents,
                            get_modules, get_modules_info)
     from travis_helpers import fail_msg, print_flush, success_msg
-else:
+except ImportError:
     from .getaddons import (get_addons, get_applications_with_dependencies,
-                            get_dependencies,
-                            get_localizations_with_dependents, get_modules,
-                            get_modules_info)
+                            get_dependencies, get_localizations_with_dependents,
+                            get_modules, get_modules_info)
     from .travis_helpers import fail_msg, print_flush, success_msg
 try:
     import ConfigParser
 except ImportError:
     import configparser as ConfigParser
 
-__version__ = '2.0.0'
+__version__ = '2.0.1'
 
 LDIR = ('server/openerp', 'odoo/odoo', 'openerp', 'odoo')
 
@@ -608,8 +607,8 @@ def main(argv=None):
         os.environ.get("DATA_DIR", os.path.expanduser('~/data_dir'))
     )
     test_enable = str2bool(os.environ.get('TEST_ENABLE', True))
-    dbtemplate = os.environ.get('MQT_TEMPLATE_DB', 'openerp_template')
-    database = os.environ.get('MQT_TEST_DB', 'openerp_test')
+    dbtemplate = os.environ.get('MQT_TEMPLATE_DB', 'template_odoo')
+    database = os.environ.get('MQT_TEST_DB', 'test_odoo')
     opts, test_loglevel, test_loghandler = get_log_level(
         odoo_version, test_enable, travis_debug_mode
     )
@@ -760,7 +759,11 @@ def main(argv=None):
                 with open('stdout.log', 'wb') as stdout:
                     for line in iter(pipe.stdout.readline, b''):
                         stdout.write(line)
-                        print(line.strip().decode('UTF-8', errors='backslashreplace'))
+                        if sys.version_info[0] == 2:
+                            print(line.strip())
+                        else:
+                            print(line.strip().decode(
+                                'utf-8', errors='backslashreplace'))
                 returncode = pipe.wait()
                 # Find errors, except from failed mails
                 errors = has_test_errors(
